@@ -151,7 +151,7 @@ def collapse_micheline(code) -> dict:
 
         if node['prim'] in ['pair', 'or']:
             res = Nested(node['prim'], args)
-            is_struct = node['prim'] == 'pair' and (typename or fieldname)
+            is_struct = node['prim'] == 'pair' and (typename or fieldname or entry)
             if is_struct or parent_prim != node['prim']:
                 args = get_flat_nested(res)
             else:
@@ -484,10 +484,15 @@ def make_default(bin_types: dict, root='0'):
     return encode_node(root)
 
 
-def michelson_to_micheline(data):
+def michelson_to_micheline(data, parser=None):
     """
     Converts michelson source text into Micheline expression
     :param data: Michelson string
+    :param parser: custom Michelson parser
     :return: Micheline expression
     """
-    return michelson_parser().parse(data)
+    if parser is None:
+        parser = michelson_parser()
+    if data[0] == '(' and data[-1] == ')':
+        data = data[1:-1]
+    return parser.parse(data)
